@@ -7,9 +7,10 @@ Name: gif2png
 Version: $version
 Release: 1
 Summary: tools for converting websites from using GIFs to using PNGs
-Source: locke.ccil.org:/pub/esr/gif2png-$version.tar.gz
+Source: locke.ccil.org:/pub/esr/gif2png/gif2png-${version}.tar.gz
 Copyright: MIT-like
 Group: Graphics
+%undefine __check_files
 
 %%description 
 Tools for converting GIFs to PNGs.  The program gif2png converts GIF files 
